import unittest

import atc


class TestSparkImport(unittest.TestCase):
    def test_spark(self):
        Spark = atc.spark


if __name__ == "__main__":
    unittest.main()
